WriteCb

Type Alias WriteCb 

pub type WriteCb = fn(i32, u8, &[u8]);
Callback for writes to device. The first argument is a counter that starts with 0 and is increment each time the callback function is called. The counter can be used to differentiate calls to the function in tests.